==> quantlib_1.15.orig.tar.gz: QuantLib-1.15/README.md <==

QuantLib: the free/open-source library for quantitative finance
===============================================================

[![Download](https://api.bintray.com/packages/quantlib/releases/QuantLib/images/download.svg)](https://bintray.com/quantlib/releases/QuantLib/_latestVersion)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.1440997.svg)](https://doi.org/10.5281/zenodo.1440997)
[![Build Status](https://travis-ci.org/lballabio/QuantLib.svg?branch=master)](https://travis-ci.org/lballabio/QuantLib)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/b4bc1058db994f24aa931b119a885eea)](https://www.codacy.com/app/lballabio/QuantLib)
[![Code Quality: Cpp](https://img.shields.io/lgtm/grade/cpp/g/lballabio/QuantLib.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/lballabio/QuantLib/context:cpp)
[![codecov](https://codecov.io/gh/lballabio/QuantLib/branch/master/graph/badge.svg)](https://codecov.io/gh/lballabio/QuantLib)
[![Average time to resolve an issue](http://isitmaintained.com/badge/resolution/lballabio/QuantLib.svg)](http://isitmaintained.com/project/lballabio/QuantLib)

---

The QuantLib project (<http://quantlib.org>) is aimed at providing a
comprehensive software framework for quantitative finance. QuantLib is
a free/open-source library for modeling, trading, and risk management
in real-life.

QuantLib is Non-Copylefted Free Software and OSI Certified Open Source
Software.


Download and usage
------------------

QuantLib can be downloaded from <http://quantlib.org/download.shtml>;
installation instructions are available at
<http://quantlib.org/install.shtml> for most platforms.

Documentation for the usage and the design of the QuantLib library is
available from <http://quantlib.org/docs.shtml>.

A list of changes for each past versions of the library can be
browsed at <http://quantlib.org/reference/history.html>.


Questions and feedback
----------------------

The preferred channel for questions (and the one with the largest
audience) is the quantlib-users mailing list.  Instructions for
subscribing are at <http://quantlib.org/mailinglists.shtml>.

Bugs can be reported as a GitHub issue at
<https://github.com/lballabio/QuantLib/issues>; if you have a patch
available, you can open a pull request instead (see "Contributing"
below).


Contributing
------------

The preferred way to contribute is through pull requests on GitHub.
Get a GitHub account if you don't have it already and clone the
repository at <https://github.com/lballabio/QuantLib> with the "Fork"
button in the top right corner of the page. Check out your clone to
your machine, code away, push your changes to your clone and submit a
pull request; instructions are available at
<https://help.github.com/articles/fork-a-repo>.

In case you need them, more detailed instructions for creating pull
requests are at
<https://help.github.com/articles/using-pull-requests>, and a basic
guide to GitHub is at
<https://guides.github.com/activities/hello-world/>.  GitHub also
provides interactive learning at <https://lab.github.com/>.

It's likely that we won't merge your code right away, and we'll ask
for some changes instead. Don't be discouraged! That's normal; the
library is complex, and thus it might take some time to become
familiar with it and to use it in an idiomatic way.

We're looking forward to your contributions.

==> quantlib_1.17.orig.tar.gz: QuantLib-1.17/README.md <==

# QuantLib: the free/open-source library for quantitative finance

[![Download](https://api.bintray.com/packages/quantlib/releases/QuantLib/images/download.svg)](https://bintray.com/quantlib/releases/QuantLib/_latestVersion)
[![Licensed under the BSD 3-Clause License](https://img.shields.io/badge/License-BSD--3--Clause-blue.svg)](https://github.com/lballabio/QuantLib/blob/master/LICENSE.TXT)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.1440997.svg)](https://doi.org/10.5281/zenodo.1440997)
[![Build Status](https://travis-ci.org/lballabio/QuantLib.svg?branch=master)](https://travis-ci.org/lballabio/QuantLib)
[![PRs Welcome](https://img.shields.io/badge/PRs%20-welcome-brightgreen.svg)](#contributing)

[![Codacy Badge](https://api.codacy.com/project/badge/Grade/b4bc1058db994f24aa931b119a885eea)](https://www.codacy.com/app/lballabio/QuantLib)
[![Code Quality: Cpp](https://img.shields.io/lgtm/grade/cpp/g/lballabio/QuantLib.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/lballabio/QuantLib/context:cpp)
[![codecov](https://codecov.io/gh/lballabio/QuantLib/branch/master/graph/badge.svg)](https://codecov.io/gh/lballabio/QuantLib)
[![Average time to resolve an issue](http://isitmaintained.com/badge/resolution/lballabio/QuantLib.svg)](http://isitmaintained.com/project/lballabio/QuantLib)

---

The QuantLib project (<http://quantlib.org>) is aimed at providing a
comprehensive software framework for quantitative finance. QuantLib is
a free/open-source library for modeling, trading, and risk management
in real-life.

QuantLib is Non-Copylefted Free Software and OSI Certified Open Source
Software.


## Download and usage

QuantLib can be downloaded from <http://quantlib.org/download.shtml>;
installation instructions are available at
<http://quantlib.org/install.shtml> for most platforms.

Documentation for the usage and the design of the QuantLib library is
available from <http://quantlib.org/docs.shtml>.

A list of changes for each past versions of the library can be
browsed at <http://quantlib.org/reference/history.html>.


## Questions and feedback

The preferred channel for questions (and the one with the largest
audience) is the quantlib-users mailing list.  Instructions for
subscribing are at <http://quantlib.org/mailinglists.shtml>.

Bugs can be reported as a GitHub issue at
<https://github.com/lballabio/QuantLib/issues>; if you have a patch
available, you can open a pull request instead (see "Contributing"
below).


## Contributing

The preferred way to contribute is through pull requests on GitHub.
Get a GitHub account if you don't have it already and clone the
repository at <https://github.com/lballabio/QuantLib> with the "Fork"
button in the top right corner of the page. Check out your clone to
your machine, code away, push your changes to your clone and submit a
pull request; instructions are available at
<https://help.github.com/articles/fork-a-repo>.

In case you need them, more detailed instructions for creating pull
requests are at
<https://help.github.com/articles/using-pull-requests>, and a basic
guide to GitHub is at
<https://guides.github.com/activities/hello-world/>.  GitHub also
provides interactive learning at <https://lab.github.com/>.

It's likely that we won't merge your code right away, and we'll ask
for some changes instead. Don't be discouraged! That's normal; the
library is complex, and thus it might take some time to become
familiar with it and to use it in an idiomatic way.

We're looking forward to your contributions.
